]> git.sesse.net Git - cubemap/blobdiff - client.h
Rename bytes_sent to stream_pos, because that is what it really is.
[cubemap] / client.h
index e82b48758d677740132498f2ca1049151fd34250..47770d19e820d0ba472ab8f576bb24f17e88f0c2 100644 (file)
--- a/client.h
+++ b/client.h
@@ -59,8 +59,9 @@ struct Client {
        // or SENDING_ERROR.
        size_t header_or_error_bytes_sent;
 
-       // Number of bytes we've sent of data. Only relevant for SENDING_DATA.
-       size_t bytes_sent;
+       // Number of bytes we are into the stream (ie., the end of last send).
+       // Only relevant for SENDING_DATA.
+       size_t stream_pos;
 };
 
 #endif  // !defined(_CLIENT_H)